# pyJXL

pyjxl is an experimental decoder for JPEG-XL .jxl files in Python.

pyjxl's primary goals are being an easy to understand decoder and enabling experimentation.
It's not meant to be performant or complete.
Please use [`libjxl`](https://github.com/libjxl/libjxl) instead for actual decoding purposes.



